2022-06-30 Version: 2.2.1
- App manage open api.

2022-06-30 Version: 2.2.0
- Support cluster resource .

2022-06-30 Version: 2.1.6
- App manage open api.

2022-06-23 Version: 2.1.5
- App manage open api.

2022-06-23 Version: 2.1.4
- Supported open api for console.

2022-05-31 Version: 2.1.3
- Add TotalCount in response of ListAppSessions.

2022-05-20 Version: 2.1.2
- CreateAppSession support postpaid.

2022-04-12 Version: 2.0.2
- Add CreateAppSessionBatch api.

